@@ -1,13 +1,13 @@
 /***************************************
-  $Header: /home/amb/procmeter3/RCS/module.c 1.9 1999/12/04 16:55:45 amb Exp $
+  $Header: /home/amb/procmeter3/RCS/module.c 1.16 2008/05/05 18:45:17 amb Exp $
 
-  ProcMeter - A system monitoring program for Linux - Version 3.2.
+  ProcMeter - A system monitoring program for Linux - Version 3.5b.
 
   Module handling functions.
   ******************/ /******************
   Written by Andrew M. Bishop
 
-  This file Copyright 1998,99 Andrew M. Bishop
+  This file Copyright 1998-2008 Andrew M. Bishop
   It may be distributed under the GNU Public License, version 2, or
   any higher version.  See section COPYING of the GNU Public license
   for conditions under which this file may be redistributed.
@@ -16,6 +16,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#include <locale.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -47,6 +48,10 @@ void LoadAllModules(void)
  Modules=(Module*)malloc(16*sizeof(Module));
  *Modules=NULL;
 
+ /* set LC_NUMERIC to C, else 0.1 in /proc/loadavg may not be parsed */
+
+ setlocale(LC_NUMERIC, "C");
+
  /* Load the library modules */
 
  if(!(library=GetProcMeterRC("library","path")))
@@ -71,18 +76,12 @@ void LoadAllModules(void)
     exit(1);
    }
 
- ent=readdir(dir);  /* skip .  */
- if(ent)
-   {
-    ent=readdir(dir);  /* skip .. */
-
-    while((ent=readdir(dir)))
-       if(!strcmp(ent->d_name+strlen(ent->d_name)-3,".so"))
-         {
-          strcpy(libp,ent->d_name);
-          LoadModule(lib);
-         }
-   }
+ while((ent=readdir(dir)))
+    if(!strcmp(ent->d_name+strlen(ent->d_name)-3,".so"))
+      {
+       strcpy(libp,ent->d_name);
+       LoadModule(lib);
+      }
 
  closedir(dir);
 
@@ -303,6 +302,8 @@ Module LoadModule(char* filename)
           new->outputs[noutputs]->output=output;
           new->outputs[noutputs]->type=t;
           new->outputs[noutputs]->first=0;
+          new->outputs[noutputs]->menu_item_widget=NULL;
+          new->outputs[noutputs]->output_widget=NULL;
 
           if(!(string=GetProcMeterRC2(new->module->name,output->name,"run")))
              string=GetProcMeterRC(new->module->name,"run");
@@ -310,7 +311,7 @@ Module LoadModule(char* filename)
 
           if(!(string=GetProcMeterRC2(new->module->name,output->name,"label")))
             {
-             static char newstr[16];
+             static char newstr[PROCMETER_NAME_LEN+1];
              int i;
              for(i=0;output->name[i];i++)
                 if(output->name[i]=='_')
@@ -321,8 +322,8 @@ Module LoadModule(char* filename)
              string=newstr;
             }
 
-          strncpy(new->outputs[noutputs]->label,string,16);
-          new->outputs[noutputs]->label[15]=0;
+          strncpy(new->outputs[noutputs]->label,string,PROCMETER_NAME_LEN+1);
+          new->outputs[noutputs]->label[PROCMETER_NAME_LEN]=0;
 
           noutputs++;
          }
@@ -333,6 +334,9 @@ Module LoadModule(char* filename)
 
  /* Add to the menus */
 
+ new->menu_item_widget=NULL;
+ new->submenu_widget=NULL;
+
  AddModuleToMenu(new);
 
  return(new);
@@ -370,8 +374,8 @@ void UnloadModule(Module module)
           *modules=*(modules+1);
           modules++;
          }
-
-    modules++;
+    else
+       modules++;
    }
 
  if(module->outputs)
@@ -391,3 +395,61 @@ void UnloadModule(Module module)
  free(module->filename);
  free(module);
 }
+
+
+#define INCSIZE 256             /*+ The buffer increment size +*/
+
+/*++++++++++++++++++++++++++++++++++++++
+  Call fgets and realloc the buffer as needed to get a whole line.
+
+  char *fgets_realloc Returns the modified buffer (NULL at the end of the file).
+
+  char **buffer A pointer to the location of the buffer (pointer to NULL to intialise a new one).
+
+  size_t *length A pointer to the current length of the buffer or the intial length if buffer is NULL.
+
+  FILE *file The file to read from.
+  ++++++++++++++++++++++++++++++++++++++*/
+
+char *fgets_realloc(char **buffer,size_t *length,FILE *file)
+{
+ int n=0;
+ char *buf;
+
+ if(!*buffer)
+   {
+    if(!*length)
+       *length=INCSIZE;
+
+    *buffer=(char*)malloc(*length);
+
+//    fprintf(stderr,"Pointer %p allocated    %4u bytes\n",buffer,*length);
+
+    if(!*buffer)
+      {*length=0;return(NULL);}
+   }
+
+ while((buf=fgets(*buffer+n,*length-n,file)))
+   {
+    int s=strlen(buf);
+    n+=s;
+
+    if((*buffer)[n-1]=='\n')
+       break;
+    else
+      {
+       *length+=INCSIZE;
+       *buffer=(char*)realloc(*buffer,*length);
+
+//       fprintf(stderr,"Pointer %p re-allocated %4u bytes\n",buffer,*length);
+
+       if(!*buffer)
+         {*length=0;return(NULL);}
+      }
+   }
+
+ if(!buf)
+   {**buffer=0;return(NULL);}
+ else
+    return(*buffer);
+}
