@@ -1,13 +1,13 @@
 /***************************************
-  $Header: /home/amb/procmeter3/modules/RCS/df.c 1.6 1999/12/12 14:08:02 amb Exp $
+  $Header: /home/amb/procmeter3/modules/RCS/df.c 1.12 2007/02/16 09:27:07 amb Exp $
 
-  ProcMeter - A system monitoring program for Linux - Version 3.2.
+  ProcMeter - A system monitoring program for Linux - Version 3.4f.
 
   Disk capacity monitoring source file.
   ******************/ /******************
   Written by Andrew M. Bishop
 
-  This file Copyright 1998,99 Andrew M. Bishop
+  This file Copyright 1998,99,2002,05 Andrew M. Bishop
   It may be distributed under the GNU Public License, version 2, or
   any higher version.  See section COPYING of the GNU Public license
   for conditions under which this file may be redistributed.
@@ -29,27 +29,27 @@ ProcMeterOutput _outputs[2]=
 {
  /*+ The percentage used space +*/
  {
-  /* char  name[16];         */ "DF_Used_%s",
-  /* char *description;      */ "The percentage of the %s device mounted on %s that is occupied with files.  "
-                                "(This can exceed 100%% on UNIX format drives due to the reserved minimum free space.)",
-  /* char  type;             */ PROCMETER_GRAPH|PROCMETER_TEXT|PROCMETER_BAR,
-  /* short interval;         */ 10,
-  /* char  text_value[16];   */ "unknown",
-  /* long  graph_value;      */ 0,
-  /* short graph_scale;      */ 10,
-  /* char  graph_units[8];   */ "(%d%%)"
+  /* char  name[];         */ "DF_Used_%s",
+  /* char *description;    */ "The percentage of the %s device mounted on %s that is occupied with files.  "
+                              "(This can exceed 100%% on UNIX format drives due to the reserved minimum free space.)",
+  /* char  type;           */ PROCMETER_GRAPH|PROCMETER_TEXT|PROCMETER_BAR,
+  /* short interval;       */ 10,
+  /* char  text_value[];   */ "unknown",
+  /* long  graph_value;    */ 0,
+  /* short graph_scale;    */ 20,
+  /* char  graph_units[];  */ "(%d%%)"
  },
  /*+ The amount of free space +*/
  {
-  /* char  name[16];         */ "DF_Free_%s",
-  /* char *description;      */ "The amount of space on the %s device mounted on %s that is available for non-root use.  "
-                                "(This can be negative on UNIX format drives since it does not include the reserved minimum free space.)",
-  /* char  type;             */ PROCMETER_TEXT,
-  /* short interval;         */ 10,
-  /* char  text_value[16];   */ "0 MB",
-  /* long  graph_value;      */ -1,
-  /* short graph_scale;      */ 0,
-  /* char  graph_units[8];   */ "n/a"
+  /* char  name[];         */ "DF_Free_%s",
+  /* char *description;    */ "The amount of space on the %s device mounted on %s that is available for non-root use.  "
+                              "(This can be negative on UNIX format drives since it does not include the reserved minimum free space.)",
+  /* char  type;           */ PROCMETER_TEXT,
+  /* short interval;       */ 10,
+  /* char  text_value[];   */ "0 MB",
+  /* long  graph_value;    */ -1,
+  /* short graph_scale;    */ 0,
+  /* char  graph_units[];  */ "n/a"
  }
 };
 
@@ -60,8 +60,8 @@ ProcMeterOutput **outputs=NULL;
 /*+ The module. +*/
 ProcMeterModule module=
 {
- /* char name[16];           */ "DiskUsage",
- /* char *description;       */ "The fraction of the disk that is occupied and the amount of space available."
+ /* char name[];           */ "DiskUsage",
+ /* char *description;     */ "The fraction of the disk that is occupied and the amount of space available."
 };
 
 
@@ -95,7 +95,7 @@ ProcMeterModule *Load(void)
 ProcMeterOutput **Initialise(char *options)
 {
  FILE *f;
- char line[128];
+ char line[256];
 
  outputs=(ProcMeterOutput**)malloc(sizeof(ProcMeterOutput*));
  outputs[0]=NULL;
@@ -107,18 +107,18 @@ ProcMeterOutput **Initialise(char *options)
     fprintf(stderr,"ProcMeter(%s): Could not open '/proc/mounts'.\n",__FILE__);
  else
    {
-    if(!fgets(line,128,f))
+    if(!fgets(line,256,f))
        fprintf(stderr,"ProcMeter(%s): Could not read '/proc/mounts'.\n",__FILE__);
     else
        do
          {
-          char device[32],mount[32];
+          char device[65],mount[65];
 
-          if(sscanf(line,"%s %s",device,mount)==2)
-             if(!strchr(device,':') && strcmp(mount,"none") && *device=='/' && *mount=='/')
+          if(sscanf(line,"%64s %64s",device,mount)==2)
+             if(strcmp(mount,"none") && *mount=='/' && (*device=='/' || strstr(device, ":/")))
                 add_disk(device,mount);
          }
-       while(fgets(line,128,f));
+       while(fgets(line,256,f));
 
     fclose(f);
    }
@@ -130,21 +130,21 @@ ProcMeterOutput **Initialise(char *options)
     fprintf(stderr,"ProcMeter(%s): Could not open '/etc/fstab'.\n",__FILE__);
  else
    {
-    if(!fgets(line,128,f))
+    if(!fgets(line,256,f))
        fprintf(stderr,"ProcMeter(%s): Could not read '/etc/fstab'.\n",__FILE__);
     else
        do
          {
-          char device[33],mount[33];
+          char device[65],mount[65];
 
           if(*line=='#')
              continue;
 
-          if(sscanf(line,"%32s %32s",device,mount)==2)
-             if(!strchr(device,':') && strcmp(mount,"none") && *device=='/' && *mount=='/')
+          if(sscanf(line,"%64s %64s",device,mount)==2)
+             if(strcmp(mount,"none") && *mount=='/' && (*device=='/' || strstr(device, ":/")))
                 add_disk(device,mount);
          }
-       while(fgets(line,128,f));
+       while(fgets(line,256,f));
 
     fclose(f);
    }
@@ -208,10 +208,7 @@ static void add_disk(char *dev,char *mnt)
     outputs[j]=(ProcMeterOutput*)malloc(sizeof(ProcMeterOutput));
 
     *outputs[j]=_outputs[i];
-    if(strlen(mnt)>7)
-      {char old=mnt[7];mnt[7]=0;sprintf(outputs[j]->name,_outputs[i].name,mnt);mnt[7]=old;}
-    else
-       sprintf(outputs[j]->name,_outputs[i].name,mnt);
+    snprintf(outputs[j]->name,PROCMETER_NAME_LEN+1,_outputs[i].name,mnt);
     outputs[j]->description=(char*)malloc(strlen(dev)+strlen(mnt)+strlen(_outputs[i].description)+4);
     sprintf(outputs[j]->description,_outputs[i].description,dev,mnt);
    }
@@ -248,7 +245,7 @@ int Update(time_t now,ProcMeterOutput *output)
  if(now!=last)
    {
     FILE *f;
-    char line[128];
+    char line[256];
 
     for(i=0;i<ndisks;i++)
        mounted[i]=0;
@@ -258,20 +255,20 @@ int Update(time_t now,ProcMeterOutput *output)
        return(-1);
     else
       {
-       if(!fgets(line,128,f))
+       if(!fgets(line,256,f))
           return(-1);
        else
           do
             {
-             char device[32],mount[32];
+             char device[65],mount[65];
 
-             if(sscanf(line,"%s %s",device,mount)==2)
-                if(strcmp(device,"none") && !strchr(device,':') && *mount=='/')
+             if(sscanf(line,"%64s %64s",device,mount)==2)
+                if(strcmp(mount,"none") && *mount=='/' && (*device=='/' || strstr(device, ":/")))
                    for(i=0;i<ndisks;i++)
                       if(!strcmp(disk[i],mount))
                          mounted[i]=1;
             }
-          while(fgets(line,128,f));
+          while(fgets(line,256,f));
 
        fclose(f);
       }
@@ -284,17 +281,21 @@ int Update(time_t now,ProcMeterOutput *output)
       {
        struct statfs buf;
 
-       if(!mounted[i/2] || statfs(disk[i/2],&buf))
+       if(!mounted[i/2])
          {
           output->graph_value=0;
-          strcpy(output->text_value,"unknown");
+          strcpy(output->text_value,"not found");
+         }
+       else if(statfs(disk[i/2],&buf))
+         {
+          output->graph_value=0;
+          strcpy(output->text_value,"statfs error");
          }
        else
          {
           if(i%2)
             {
-             long avail=(buf.f_bavail>>10)*buf.f_bsize;
-
+             long avail=(buf.f_bavail>>5)*(buf.f_bsize>>5);
              sprintf(output->text_value,"%.1f MB",avail/1024.0);
             }
           else
