@@ -1,7 +1,7 @@
 /***************************************
-  $Header: /home/amb/procmeter3/modules/RCS/sensors.c 1.7 2004/03/19 19:00:53 amb Exp $
+  $Header: /home/amb/procmeter3/modules/RCS/sensors.c 1.9 2007/09/07 16:19:06 amb Exp $
 
-  ProcMeter - A system monitoring program for Linux - Version 3.4b.
+  ProcMeter - A system monitoring program for Linux - Version 3.4c.
 
   Temperature indicators for Mainboard and CPU
   Based on loadavg.c, stat-cpu.c by Andrew M. Bishop
@@ -9,7 +9,7 @@
   Written by Matt Kemner, Andrew M. Bishop
 
   This file Copyright 1999 Matt Kemner, Andrew M. Bishop
-  parts of it are Copyright 1998,99,2002,04 Andrew M. Bishop
+  parts of it are Copyright 1998,99,2002,04,07 Andrew M. Bishop
   It may be distributed under the GNU Public License, version 2, or
   any higher version.  See section COPYING of the GNU Public license
   for conditions under which this file may be redistributed.
@@ -65,8 +65,8 @@ ProcMeterOutput **outputs=NULL;
 ProcMeterModule module=
 {
  /* char name[];           */ "Sensors",
- /* char *description;     */ "Hardware status information, temperature, fan speed etc. [From /proc/sys/dev/sensors/*/*]"
-                              " (Requires version 2.x.x of lm78 sensors from http://www.netroedge.com/~lm78/).",
+ /* char *description;     */ "Hardware status information, temperature, fan speed etc."
+                              " (Requires lm_sensors patch from http://www.netroedge.com/~lm78/ or version 2.6 kernel).",
 };
 
 /*+ The temperature outputs. +*/
@@ -121,6 +121,7 @@ ProcMeterOutput **Initialise(char *options)
  struct dirent* ent1,*ent2;
  char *dirstart=NULL;
  struct stat buf;
+ int kernel_2_6_22 = 0;
  int n=0,i;
 
  /* Find the directory with the sensor information in it. */
@@ -130,6 +131,12 @@ ProcMeterOutput **Initialise(char *options)
     dirstart="/proc/sys/dev/sensors";
     kernel_2_6_0=0;
    }
+ else if((d1=opendir("/sys/class/hwmon"))) /* kernel >= 2.6.22 */
+   {
+    dirstart="/sys/class/hwmon";
+    kernel_2_6_22=1;
+    kernel_2_6_0=1;
+   }
  else if((d1=opendir("/sys/bus/i2c/devices"))) /* kernel >= 2.6.0 */
    {
     dirstart="/sys/bus/i2c/devices";
@@ -147,7 +154,11 @@ ProcMeterOutput **Initialise(char *options)
        if(!strcmp(ent1->d_name,".."))
           continue;
 
-       sprintf(dirname,"%s/%s",dirstart,ent1->d_name);
+       if (kernel_2_6_22)     /* kernel >= 2.6.22 */
+         sprintf(dirname,"%s/%s/%s",dirstart,ent1->d_name,"device");
+       else                   /* kernel < 2.6.22 */
+         sprintf(dirname,"%s/%s",dirstart,ent1->d_name);
+
        if(stat(dirname,&buf)==0 && S_ISDIR(buf.st_mode))
          {
           d2=opendir(dirname);
@@ -168,18 +179,30 @@ ProcMeterOutput **Initialise(char *options)
                 if(stat(filename,&buf)!=0 || !S_ISREG(buf.st_mode))
                    continue;
 
-                if(!strcmp(ent2->d_name,"temp"))
-                   add_temperature(filename);
+                if(!strncmp(ent2->d_name,"temp",4))
+                  {
+                   if(!ent2->d_name[4])
+                      add_temperature(filename);
+                   else if(isdigit(ent2->d_name[4]) && !ent2->d_name[5]) /* kernel < 2.6.0 */
+                      add_temperature(filename);
+                   else if(isdigit(ent2->d_name[4]) && !strcmp(ent2->d_name+5,"_input")) /* kernel >= 2.6.0 */
+                      add_temperature(filename);
+                   else if(!strncmp(ent2->d_name+5,"_input",6) && isdigit(ent2->d_name[10]) && !ent2->d_name[11]) /* kernel >= 2.6.0 */
+                      add_temperature(filename);
+                  }
                 else if(!strcmp(ent2->d_name,"remote_temp"))
                    add_temperature(filename);
-                else if(!strncmp(ent2->d_name,"temp",4) && isdigit(ent2->d_name[4]) && !ent2->d_name[5]) /* kernel < 2.6.0 */
-                   add_temperature(filename);
-                else if(!strncmp(ent2->d_name,"temp_input",10) && isdigit(ent2->d_name[10]) && !ent2->d_name[11]) /* kernel >= 2.6.0 */
-                   add_temperature(filename);
-                else if(!strncmp(ent2->d_name,"fan",3) && isdigit(ent2->d_name[3]) && !ent2->d_name[4]) /* kernel < 2.6.0 */
-                   add_fan(filename);
-                else if(!strncmp(ent2->d_name,"fan_input",9) && isdigit(ent2->d_name[9]) && !ent2->d_name[10]) /* kernel >= 2.6.0 */
-                   add_fan(filename);
+                else if(!strncmp(ent2->d_name,"fan",3))
+                  {
+                   if(!ent2->d_name[3])
+                      add_fan(filename);
+                   else if(isdigit(ent2->d_name[3]) && !ent2->d_name[4]) /* kernel < 2.6.0 */
+                      add_fan(filename);
+                   else if(isdigit(ent2->d_name[3]) && !strcmp(ent2->d_name+4,"_input")) /* kernel >= 2.6.0 */
+                      add_fan(filename);
+                   else if(!strncmp(ent2->d_name+4,"_input",6) && isdigit(ent2->d_name[9]) && !ent2->d_name[10]) /* kernel >= 2.6.0 */
+                      add_fan(filename);
+                  }
                }
 
              closedir(d2);
