@@ -1,13 +1,13 @@
 /***************************************
-  $Header: /home/amb/procmeter3/RCS/procmeter.h 1.16 2004/04/25 08:02:14 amb Exp $
+  $Header: /home/amb/procmeter3/RCS/procmeter.h 1.24 2008/05/05 18:45:17 amb Exp $
 
-  ProcMeter - A system monitoring program for Linux - Version 3.4b.
+  ProcMeter - A system monitoring program for Linux - Version 3.5b.
 
   Global public header file.
   ******************/ /******************
   Written by Andrew M. Bishop
 
-  This file Copyright 1998,99,2000,01,02,03,04 Andrew M. Bishop
+  This file Copyright 1998-2008 Andrew M. Bishop
   It may be distributed under the GNU Public License, version 2, or
   any higher version.  See section COPYING of the GNU Public license
   for conditions under which this file may be redistributed.
@@ -18,13 +18,14 @@
 #define PROCMETER_H    /*+ To stop multiple inclusions. +*/
 
 #include <time.h>
+#include <stdio.h>
 
 
-#define PROCMETER_VERSION "3.4b"
+#define PROCMETER_VERSION "3.5b"
 
 
 #define PROCMETER_MAJOR_VERSION 3
-#define PROCMETER_MINOR_VERSION 4
+#define PROCMETER_MINOR_VERSION 5
 
 
 #define PROCMETER_GRAPH 1
@@ -75,7 +76,7 @@ typedef struct _ProcMeterModule
 ProcMeterModule;
 
 
-/* The funtions exported from the modules. */
+/* The funtions that must be exported from the modules. */
 
 ProcMeterModule *Load(void);
 
@@ -86,4 +87,9 @@ int Update(time_t now,ProcMeterOutput *output);
 void Unload(void);
 
 
+/* The functions available to the modules. */
+
+char *fgets_realloc(char **buffer,size_t *length,FILE *file);
+
+
 #endif /* PROCMETER_H */
